<?php

/**
	AppSys - An application management system for PhD programs funded by the DFG.
	Copyright (C) 2010 Florian Junghanns

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
**/


// custom_functions.php - Custom functions, optimized for this application

function app_get ($conditions) {
	$str_SQL = "SELECT
				`applications`.`id` AS `id`, 
				`title`,
				`firstname`,
				`lastname`,
				`gender`,
				`birthday`,
				`place`,
				`my_country`.`name` AS `country`,
				`my_country`.`code` AS `country_id`,
				`nationalities`.`name` AS `nationality`,
				`nationalities`.`id` AS `nationality_id`,
				`applications`.`email`,
				`inst_name`,
				`inst_place`,
				`inst_country`.`name` AS `inst_country`,
				`inst_country`.`code` AS `inst_country_id`,
				`degree`,
				`gpa`,
				`grad_year`,
				`grad_title`,
				`topic_1`,
				`topic_2`,
				`topic_3`,
				`advisor1`.`id` AS `advisor_1_id`,
				`advisor1`.`realname` AS `advisor_1`,
				`advisor1`.`shortname` AS `advisor_1_short`,
				`advisor2`.`id` AS `advisor_2_id`,
				`advisor2`.`realname` AS `advisor_2`,
				`advisor2`.`shortname` AS `advisor_2_short`,
				`advisor3`.`id` AS `advisor_3_id`,
				`advisor3`.`realname` AS `advisor_3`,
				`advisor3`.`shortname` AS `advisor_3_short`,
				`files`.`id` AS `fileid`,
				`files`.`name` AS `uploaded_file`,
				`files`.`sysname` AS `file_sysname`,
				`statuses`.`name` AS `status`,
				`statuses`.`id` AS `status_id`,
				`notice`,
				`date`
				FROM
				(SELECT * FROM `applications` ORDER BY `date` DESC) AS `applications`,
				`countries` AS `my_country`,
				`nationalities`,
				`countries` AS `inst_country`,
				`user` AS `advisor1`,
				`user` AS `advisor2`,
				`user` AS `advisor3`,
				`files`,
				`statuses`
				WHERE
				`country` = `my_country`.`code`
				AND `nationality` = `nationalities`.`id`
				AND `inst_country` = `inst_country`.`code`
				AND `advisor_1` = `advisor1`.`id`
				AND `advisor_2` = `advisor2`.`id`
				AND `advisor_3` = `advisor3`.`id`
				AND `fileid` = `files`.`id`
				AND `applications`.`status` = `statuses`.`id`
				".$conditions.";";
	$temp = mysqlib_get($str_SQL, 2);
	return $temp;
}


function apptable_create_rows ($applications, $backlink) {
	if($applications) {
		$lines = "";
		foreach($applications AS $record) {
			$temp = template_basic("overview_table_row");
			$temp = str_replace("{date}", date("d.m.Y", $record[date]), $temp);
			$temp = str_replace("{name}", $record[lastname].", ".$record[firstname], $temp);
			$temp = str_replace("{nationality}", $record[nationality], $temp);
			$temp = str_replace("{advisors}", $record[advisor_1_short]
				. ($record[advisor_2] != "nobody" ? ", ".$record[advisor_2_short] : "")
				. ($record[advisor_3] != "nobody" ? ", ".$record[advisor_3_short] : ""), $temp);
			$temp = str_replace("{id}", $record[id], $temp);
			$temp = str_replace("{backlink}", $backlink, $temp);
			$temp = str_replace("{fileid}", $record[fileid], $temp);
			$lines .= $temp;
		}
		return $lines;
	} else {
		$temp = template_basic("overview_table_row_inactive");
		$temp = str_replace("{date}", "no entries", $temp);
		$temp = str_replace("{name}", "", $temp);
		$temp = str_replace("{nationality}", "", $temp);
		$temp = str_replace("{advisors}", "", $temp);
		return $temp;
	}
}

function send_mails($occasion) {
	if($occasion == "application: unchecked => new") {
		$advisors = mysqlib_get("SELECT `name`, `realname`, `email`, `lastlogin` FROM `advisors`, `user` WHERE `userid` = `id`;", 2);
		$lastvalidation = mysqlib_get("SELECT MAX(`validation`) AS `validation` FROM `applications`;", 0);
		$secretarymail = mysqlib_get("SELECT `email` FROM `user` WHERE `name` = 'Secretary';", 0);
		foreach($advisors AS $record)
			if($record[lastlogin] >= $lastvalidation || $record[lastlogin]+(60*60*24*7) < time())	// If current advisor has a) already seen recent applications	b) not been logged in for a week.
				mail($record[email],
					"GK Applications System: New application(s)!",
					str_replace("{realname}", $record[realname], 
						str_replace("{name}", $record[name], template_basic("mail_new_applications_body"))),
					'From: GK Applications System <'.$secretarymail.'>'."\r\n".'Reply-To: GK Secretary <'.$secretarymail.'>');
	}

}
