<?php

/**
	AppSys - An application management system for PhD programs funded by the DFG.
	Copyright (C) 2010 Florian Junghanns

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
**/


// ----- ----- ----- Internal edit form ----- ----- ----- //

// ----- Getting field-data ----- //
include("inc.entry_fields.php");


// ----- Checking standard field data ----- //
$data;
$properness;

foreach($postfields AS $field) {
	$length = strlen($_POST[$field["name"]]);
	switch($field["conditiontype"]) {
		case "length":
			if(!($length <= $field["value"]))
				$properness[$field["name"]] = "length";
			break;
		case "value":
			if(!($_POST[$field["name"]] == $field["value"]))
				$properness[$field["name"]] = "invalid";
			break;
		case "values":
			$values = split('/[^\\](\\\\)*\|/', $field["value"]);
			$properness[$field["name"]] = "invalid";
			foreach($values AS $value)
				if($_POST[$field["name"]] == $value) {
					unset($properness[$field["name"]]);
					break;
				}
			break;
		case "min|max":
			$minmax = explode("|", $field["value"]);
			if(!($_POST[$field["name"]] >= $minmax[0] && $_POST[$field["name"]] <= $minmax[1]))
				$properness[$field["name"]] = "invalid";
			break;
		case "regexp":
			if(!(preg_match($field["value"], $_POST[$field["name"]]) == 1))
				$properness[$field["name"]] = "invalid";
			break;
		default:
			echo "A condition is specified in a wrong way; that for field '".$field["name"]."'!";
	}
	if($length == 0 && !$field["optional"])
		$properness[$field["name"]] = "empty";
	$data[$field["name"]] = htmlentities($_POST[$field["name"]]);
}


// ----- Checking special field data ----- //

switch($whichForm) {


	// ----- PhD ----- //
	case "phd entry":

		// ----- Research Interest Verification and Shifting----- //
		if(isset($properness["topic_1"]) && isset($properness["topic_2"]) && isset($properness["topic_3"])
				|| ($data["topic_1"] == "" && $data["topic_2"] == "" && $data["topic_3"] == "")) {
			$properness["topic_1"] = "empty";
			unset($properness["topic_2"]);
			unset($properness["topic_3"]);
		} else if(isset($properness["topic_1"]) && (strlen($data["topic_2"]) > 0 || strlen($data["topic_3"]) > 0)) {
			unset($properness["topic_1"]);
			if(strlen($data["topic_2"]) > 0) {
				$data["topic_1"] = $data["topic_2"];
				$data["topic_2"] = "";
			} else {
				$data["topic_1"] = $data["topic_3"];
				$data["topic_3"] = "";
			}
		}

		// ----- Shifting of advisors ----- //
		if($data["advisor_1"] == 0) {
			 if($data["advisor_2"] != 0) {
				$data["advisor_1"] = $data["advisor_2"];
				$data["advisor_2"] = 0;
				if(isset($properness["advisor_2"])) {
					$properness["advisor_1"] = $properness["advisor_2"];
					unset($properness["advisor_2"]);
				} else
					unset($properness["advisor_1"]);
			} else {
				$data["advisor_1"] = $data["advisor_3"];
				$data["advisor_3"] = 0;
				if(isset($properness["advisor_3"])) {
					$properness["advisor_1"] = $properness["advisor_3"];
					unset($properness["advisor_3"]);
				} else
					unset($properness["advisor_1"]);
			}
		}
		if($data["advisor_2"] == 0 && $data["advisor_3"] != 0) {
			$data["advisor_2"] = $data["advisor_3"];
			$data["advisor_3"] = 0;
			if(isset($properness["advisor_3"])) {
				$properness["advisor_2"] = $properness["advisor_3"];
				unset($properness["advisor_3"]);
			}
		}

		// ----- File ID Verifivation ----- //
		if(!isset($properness["file_id"]))
			if(mysqlib_get("SELECT COUNT(*) FROM `file_index` WHERE `id` = '".mysqlib_secure($data["file_id"])."' AND `temporary` = '0'", 0) == 1) {
				$temp = mysqlib_get("SELECT `real_name`, `system_name` FROM `file_index` WHERE `id` = '".$data["file_id"]."'", 1);
				$data["file_id"] = array("id" => $data["file_id"]);
				$data["file_id"]["name"] = $temp["real_name"];
				$data["file_id"]["size_b"] = filesize($_settings[upload][path].$temp["system_name"]);
				$data["file_id"]["size_kb"] = round($data["file_id"]["size_b"]/1024, 2);
				$data["file_id"]["size_mb"] = round($data["file_id"]["size_b"]/(1024*1024), 2);
			} else {
				$properness["file_id"] = "empty";
				unset($data["file_id"]);
			}
		break;



	// ----- PD ----- //
	case "pd entry":

		// ----- File ID Verifivation ----- //
		if(!isset($properness["file_id"]))
			if(mysqlib_get("SELECT COUNT(*) FROM `file_index` WHERE `id` = '".mysqlib_secure($data["file_id"])."' AND `temporary` = '0'", 0) == 1) {
				$temp = mysqlib_get("SELECT `real_name`, `system_name` FROM `file_index` WHERE `id` = '".$data["file_id"]."'", 1);
				$data["file_id"] = array("id" => $data["file_id"]);
				$data["file_id"]["name"] = $temp["real_name"];
				$data["file_id"]["size_b"] = filesize($_settings[upload][path].$temp["system_name"]);
				$data["file_id"]["size_kb"] = round($data["file_id"]["size_b"]/1024, 2);
				$data["file_id"]["size_mb"] = round($data["file_id"]["size_b"]/(1024*1024), 2);
			} else {
				$properness["file_id"] = "empty";
				unset($data["file_id"]);
			}
		break;

/*
// ----------------------------------------- //
// ----- PhD Student Application Forms ----- //
// ----------------------------------------- //

// ----- ----- Checking form "phd enter" ----- ----- //
	case "phd enter":
	case "phd check":
		// ----- Gender Verification ----- //
		if(isset($properness["gender"]))
			$properness["gender"] = "empty";


		// ----- Birthday Verification ----- //
		if(!checkdate($data["birth_month"], $data["birth_day"], $data["birth_year"]))
			$properness["birth_day"] = $properness["birth_month"] = $properness["birth_year"] = "invalid";


		// ----- Country, Nationality, Country of Institution Verification ------ //
		if(!isset($properness["country"])) {
			if(mysqlib_get("SELECT COUNT(*) FROM `country` WHERE `id` = '".mysqlib_secure($data["country"])."'", 0) != 1)
				$properness["country"] = "invalid";
		} else
			$properness["country"] = "empty";

		if(!isset($properness["nationality"])) {
			 if(mysqlib_get("SELECT COUNT(*) FROM `nationality` WHERE `id` = '".mysqlib_secure($data["nationality"])."'", 0) != 1)
				$properness["nationality"] = "invalid";
		} else
			$properness["nationality"] = "empty";

		if(!isset($properness["inst_country"])) {
			 if(mysqlib_get("SELECT COUNT(*) FROM `country` WHERE `id` = '".mysqlib_secure($data["inst_country"])."'", 0) != 1)
				$properness["inst_country"] = "invalid";
		} else
			$properness["inst_country"] = "empty";


		// ----- Research Interest Verification ----- //
		if(isset($properness["topic_1"]) && isset($properness["topic_2"]) && isset($properness["topic_3"])
				|| ($data["topic_1"] == "" && $data["topic_2"] == "" && $data["topic_3"] == "")) {
			$properness["topic_1"] = "empty";
			unset($properness["topic_2"]);
			unset($properness["topic_3"]);
		} else if(isset($properness["topic_1"]) && (strlen($data["topic_2"]) > 0 || strlen($data["topic_3"]) > 0)) {
			unset($properness["topic_1"]);
			if(strlen($data["topic_2"]) > 0) {
				$data["topic_1"] = $data["topic_2"];
				$data["topic_2"] = "";
			} else {
				$data["topic_1"] = $data["topic_3"];
				$data["topic_3"] = "";
			}
		}


		// ----- Begin Advisor Verification ----- //
		$advisorCount = 0;
		if($data["advisor_1"] != 0) {
			 if(mysqlib_get("SELECT COUNT(*) FROM `user` WHERE `id` = '".mysqlib_secure($data["advisor_1"])."'", 0) != 1)
				$properness["advisor_1"] = "invalid";
			$advisorCount++;
		}

		if($data["advisor_2"] != 0) {
			 if(mysqlib_get("SELECT COUNT(*) FROM `user` WHERE `id` = '".mysqlib_secure($data["advisor_2"])."'", 0) != 1)
				$properness["advisor_2"] = "invalid";
			else if($data["advisor_1"] == $data["advisor_2"])
				$properness["advisor_2"] = "double";
			$advisorCount++;
		}

		if($data["advisor_3"] != 0) {
			 if(mysqlib_get("SELECT COUNT(*) FROM `user` WHERE `id` = '".mysqlib_secure($data["advisor_3"])."'", 0) != 1)
				$properness["advisor_3"] = "invalid";
			else if($data["advisor_1"] == $data["advisor_3"] || $data["advisor_2"] == $data["advisor_3"])
				$properness["advisor_3"] = "double";
			$advisorCount++;
		}

		if($advisorCount == 0)
			$properness["advisor_1"] = "empty";
		else
		// ----- Shifting of advisors ----- //
			if($advisorCount < 3) {
				if($data["advisor_1"] == 0)
					 if($data["advisor_2"] != 0) {
						$data["advisor_1"] = $data["advisor_2"];
						$data["advisor_2"] = 0;
						if(isset($properness["advisor_2"])) {
							$properness["advisor_1"] = $properness["advisor_2"];
							unset($properness["advisor_2"]);
						} else
							unset($properness["advisor_1"]);
					} else {
						$data["advisor_1"] = $data["advisor_3"];
						$data["advisor_3"] = 0;
						if(isset($properness["advisor_3"])) {
							$properness["advisor_1"] = $properness["advisor_3"];
							unset($properness["advisor_3"]);
						} else
							unset($properness["advisor_1"]);
					}
				if($data["advisor_2"] == 0 && $data["advisor_3"] != 0) {
					$data["advisor_2"] = $data["advisor_3"];
					$data["advisor_3"] = 0;
					if(isset($properness["advisor_3"])) {
						$properness["advisor_2"] = $properness["advisor_3"];
						unset($properness["advisor_3"]);
					}
				}
		}
		// ----- End Advisor Verification ----- //


		// ----- File ID Verifivation ----- //
		if(!isset($properness["file_id"]))
			if(mysqlib_get("SELECT COUNT(*) FROM `file_index` WHERE `id` = '".mysqlib_secure($data["file_id"])."' AND `temporary` = '0'", 0) == 1) {
				$temp = mysqlib_get("SELECT `real_name`, `system_name` FROM `file_index` WHERE `id` = '".$data["file_id"]."'", 1);
				$data["file_id"] = array("id" => $data["file_id"]);
				$data["file_id"]["name"] = $temp["real_name"];
				$data["file_id"]["size_b"] = filesize($_settings[upload][path].$temp["system_name"]);
				$data["file_id"]["size_kb"] = round($data["file_id"]["size_b"]/1024, 2);
				$data["file_id"]["size_mb"] = round($data["file_id"]["size_b"]/(1024*1024), 2);
			} else {
				$properness["file_id"] = "empty";
				unset($data["file_id"]);
			}
		break;

/*
// ----- ----- Checking form "phd review" ----- ----- //
	case "phd review":
		// ----- Gender Verification ----- //
		if(isset($properness["gender"]))
			$properness["gender"] = "empty";


		// ----- Birthday Verification ----- //
		if(isset($properness["birthday"]))
			$properness["birth_day"] = $properness["birth_month"] = $properness["birth_year"] = "invalid";


		// ----- Country, Nationality, Country of Institution Verification ------ //
		if(!isset($properness["country"])) {
			if(mysqlib_get("SELECT COUNT(*) FROM `country` WHERE `id` = '".mysqlib_secure($data["country"])."'", 0) != 1)
				$properness["country"] = "invalid";
		} else
			$properness["country"] = "empty";

		if(!isset($properness["nationality"])) {
			 if(mysqlib_get("SELECT COUNT(*) FROM `nationality` WHERE `id` = '".mysqlib_secure($data["nationality"])."'", 0) != 1)
				$properness["nationality"] = "invalid";
		} else
			$properness["nationality"] = "empty";

		if(!isset($properness["inst_country"])) {
			 if(mysqlib_get("SELECT COUNT(*) FROM `country` WHERE `id` = '".mysqlib_secure($data["inst_country"])."'", 0) != 1)
				$properness["inst_country"] = "invalid";
		} else
			$properness["inst_country"] = "empty";


		// ----- Research Interest Verification ----- //
		if(isset($properness["topic_1"]) && isset($properness["topic_2"]) && isset($properness["topic_3"])
				|| ($data["topic_1"] == "" && $data["topic_2"] == "" && $data["topic_3"] == "")) {
			$properness["topic_1"] = "empty";
			unset($properness["topic_2"]);
			unset($properness["topic_3"]);
		} else if(isset($properness["topic_1"]) && (strlen($data["topic_2"]) > 0 || strlen($data["topic_3"]) > 0)) {
			unset($properness["topic_1"]);
			if(strlen($data["topic_2"]) > 0) {
				$data["topic_1"] = $data["topic_2"];
				$data["topic_2"] = "";
			} else {
				$data["topic_1"] = $data["topic_3"];
				$data["topic_3"] = "";
			}
		}


		// ----- Begin Advisor Verification ----- //
		$advisorCount = 0;
		if($data["advisor_1"] != 0) {
			 if(mysqlib_get("SELECT COUNT(*) FROM `user` WHERE `id` = '".mysqlib_secure($data["advisor_1"])."'", 0) != 1)
				$properness["advisor_1"] = "invalid";
			$advisorCount++;
		}

		if($data["advisor_2"] != 0) {
			 if(mysqlib_get("SELECT COUNT(*) FROM `user` WHERE `id` = '".mysqlib_secure($data["advisor_2"])."'", 0) != 1)
				$properness["advisor_2"] = "invalid";
			else if($data["advisor_1"] == $data["advisor_2"])
				$properness["advisor_2"] = "double";
			$advisorCount++;
		}

		if($data["advisor_3"] != 0) {
			 if(mysqlib_get("SELECT COUNT(*) FROM `user` WHERE `id` = '".mysqlib_secure($data["advisor_3"])."'", 0) != 1)
				$properness["advisor_3"] = "invalid";
			else if($data["advisor_1"] == $data["advisor_3"] || $data["advisor_2"] == $data["advisor_3"])
				$properness["advisor_3"] = "double";
			$advisorCount++;
		}

		if($advisorCount == 0)
			$properness["advisor_1"] = "empty";
		else
		// ----- Shifting of advisors ----- //
			if($advisorCount < 3) {
				if($data["advisor_1"] == 0)
					 if($data["advisor_2"] != 0) {
						$data["advisor_1"] = $data["advisor_2"];
						$data["advisor_2"] = 0;
						if(isset($properness["advisor_2"])) {
							$properness["advisor_1"] = $properness["advisor_2"];
							unset($properness["advisor_2"]);
						} else
							unset($properness["advisor_1"]);
					} else {
						$data["advisor_1"] = $data["advisor_3"];
						$data["advisor_3"] = 0;
						if(isset($properness["advisor_3"])) {
							$properness["advisor_1"] = $properness["advisor_3"];
							unset($properness["advisor_3"]);
						} else
							unset($properness["advisor_1"]);
					}
				if($data["advisor_2"] == 0 && $data["advisor_3"] != 0) {
					$data["advisor_2"] = $data["advisor_3"];
					$data["advisor_3"] = 0;
					if(isset($properness["advisor_3"])) {
						$properness["advisor_2"] = $properness["advisor_3"];
						unset($properness["advisor_3"]);
					}
				}
		}
		// ----- End Advisor Verification ----- //


		// ----- File ID Verifivation ----- //
		if(!isset($properness["file_id"]))
			if(mysqlib_get("SELECT COUNT(*) FROM `file_index` WHERE `id` = '".mysqlib_secure($data["file_id"])."' AND `temporary` = '1'", 0) == 1) {
				$temp = mysqlib_get("SELECT `real_name`, `system_name` FROM `file_index` WHERE `id` = '".mysqlib_secure($data["file_id"])."'", 1);
				$data["file_id"] = array("id" => $data["file_id"]);
				$data["file_id"]["name"] = $temp["real_name"];
				$data["file_id"]["size_b"] = filesize($_settings[upload][path].$temp["system_name"]);
				$data["file_id"]["size_kb"] = round($data["file_id"]["size_b"]/1024, 2);
				$data["file_id"]["size_mb"] = round($data["file_id"]["size_b"]/(1024*1024), 2);
			} else {
				$properness["file_id"] = "empty";
				unset($data["file_id"]);
			}
		break;

/*
// ------------------------------------- //
// ----- PostDoc Application Forms ----- //
// ------------------------------------- //

// ----- ----- Checking forms "pd enter" and "pd check" ----- ----- //
	case "pd enter":
	case "pd check":
		// ----- Gender Verification ----- //
		if(isset($properness["gender"]))
			$properness["gender"] = "empty";


		// ----- Birthday Verification ----- //
		if(!checkdate($data["birth_month"], $data["birth_day"], $data["birth_year"]))
			$properness["birth_day"] = $properness["birth_month"] = $properness["birth_year"] = "invalid";


		// ----- Country, Nationality, Country of Institution Verification ------ //
		if(!isset($properness["country"])) {
			if(mysqlib_get("SELECT COUNT(*) FROM `country` WHERE `id` = '".mysqlib_secure($data["country"])."'", 0) != 1)
				$properness["country"] = "invalid";
		} else
			$properness["country"] = "empty";

		if(!isset($properness["nationality"])) {
			 if(mysqlib_get("SELECT COUNT(*) FROM `nationality` WHERE `id` = '".mysqlib_secure($data["nationality"])."'", 0) != 1)
				$properness["nationality"] = "invalid";
		} else
			$properness["nationality"] = "empty";

		if(!isset($properness["inst_country"])) {
			 if(mysqlib_get("SELECT COUNT(*) FROM `country` WHERE `id` = '".mysqlib_secure($data["inst_country"])."'", 0) != 1)
				$properness["inst_country"] = "invalid";
		} else
			$properness["inst_country"] = "empty";

		// ----- PhD Graduation Date Verification ----- //
		if(isset($properness["phd_month"]) || isset($properness["phd_year"]))
			$properness["phd_time"] = "invalid";
		else
		if(!checkdate($data["phd_month"], 1, $data["phd_year"]))
			$properness["phd_time"] = "invalid";
		else
			$data["phd_time"] = "";

		// ----- Research Interest Verification ----- //
		if(isset($properness["topic_1"]) && isset($properness["topic_2"]) && isset($properness["topic_3"])
				|| ($data["topic_1"] == "" && $data["topic_2"] == "" && $data["topic_3"] == "")) {
			$properness["topic_1"] = "empty";
			unset($properness["topic_2"]);
			unset($properness["topic_3"]);
		} else if(isset($properness["topic_1"]) && (strlen($data["topic_2"]) > 0 || strlen($data["topic_3"]) > 0)) {
			unset($properness["topic_1"]);
			if(strlen($data["topic_2"]) > 0) {
				$data["topic_1"] = $data["topic_2"];
				$data["topic_2"] = "";
			} else {
				$data["topic_1"] = $data["topic_3"];
				$data["topic_3"] = "";
			}
		}


		// ----- Begin Advisor Verification ----- //
		$profCount = 0;
		if($data["prof_1_id"] != 0) {
			 if(mysqlib_get("SELECT COUNT(*) FROM `user` WHERE `id` = '".mysqlib_secure($data["prof_1_id"])."'", 0) != 1)
				$properness["prof_1_id"] = "invalid";
			$profCount++;
		}

		if($data["prof_2_id"] != 0) {
			 if(mysqlib_get("SELECT COUNT(*) FROM `user` WHERE `id` = '".mysqlib_secure($data["prof_2_id"])."'", 0) != 1)
				$properness["prof_2_id"] = "invalid";
			else if($data["prof_1_id"] == $data["prof_2_id"])
				$properness["prof_2_id"] = "double";
			$profCount++;
		}

		if($data["prof_3_id"] != 0) {
			 if(mysqlib_get("SELECT COUNT(*) FROM `user` WHERE `id` = '".mysqlib_secure($data["prof_3_id"])."'", 0) != 1)
				$properness["prof_3_id"] = "invalid";
			else if($data["prof_1_id"] == $data["prof_3_id"] || $data["prof_2_id"] == $data["prof_3_id"])
				$properness["prof_3_id"] = "double";
			$profCount++;
		}

		if($profCount == 0)
			$properness["prof_1_id"] = "empty";
		// ----- End Advisor Verification ----- //


		// ----- File ID Verifivation ----- //
		if(!isset($properness["file_id"]))
			if(mysqlib_get("SELECT COUNT(*) FROM `file_index` WHERE `id` = '".mysqlib_secure($data["file_id"])."' AND `temporary` = '1'", 0) == 1) {
				$temp = mysqlib_get("SELECT `real_name`, `system_name` FROM `file_index` WHERE `id` = '".$data["file_id"]."'", 1);
				$data["file_id"] = array("id" => $data["file_id"]);
				$data["file_id"]["name"] = $temp["real_name"];
				$data["file_id"]["size_b"] = filesize($_settings[upload][path].$temp["system_name"]);
				$data["file_id"]["size_kb"] = round($data["file_id"]["size_b"]/1024, 2);
				$data["file_id"]["size_mb"] = round($data["file_id"]["size_b"]/(1024*1024), 2);
			} else {
				$properness["file_id"] = "empty";
				unset($data["file_id"]);
			}
		break;


// ----- ----- Checking form "pd review" ----- ----- //
	case "pd review":
		// ----- Gender Verification ----- //
		if(isset($properness["gender"]))
			$properness["gender"] = "empty";


		// ----- Birthday Verification ----- //
		if(isset($properness["birthday"]))
			$properness["birth_day"] = $properness["birth_month"] = $properness["birth_year"] = "invalid";


		// ----- Country, Nationality, Country of Institution Verification ------ //
		if(!isset($properness["country"])) {
			if(mysqlib_get("SELECT COUNT(*) FROM `country` WHERE `id` = '".mysqlib_secure($data["country"])."'", 0) != 1)
				$properness["country"] = "invalid";
		} else
			$properness["country"] = "empty";

		if(!isset($properness["nationality"])) {
			 if(mysqlib_get("SELECT COUNT(*) FROM `nationality` WHERE `id` = '".mysqlib_secure($data["nationality"])."'", 0) != 1)
				$properness["nationality"] = "invalid";
		} else
			$properness["nationality"] = "empty";

		if(!isset($properness["inst_country"])) {
			 if(mysqlib_get("SELECT COUNT(*) FROM `country` WHERE `id` = '".mysqlib_secure($data["inst_country"])."'", 0) != 1)
				$properness["inst_country"] = "invalid";
		} else
			$properness["inst_country"] = "empty";


		// ----- Research Interest Verification ----- //
		if(isset($properness["topic_1"]) && isset($properness["topic_2"]) && isset($properness["topic_3"])
				|| ($data["topic_1"] == "" && $data["topic_2"] == "" && $data["topic_3"] == "")) {
			$properness["topic_1"] = "empty";
			unset($properness["topic_2"]);
			unset($properness["topic_3"]);
		} else if(isset($properness["topic_1"]) && (strlen($data["topic_2"]) > 0 || strlen($data["topic_3"]) > 0)) {
			unset($properness["topic_1"]);
			if(strlen($data["topic_2"]) > 0) {
				$data["topic_1"] = $data["topic_2"];
				$data["topic_2"] = "";
			} else {
				$data["topic_1"] = $data["topic_3"];
				$data["topic_3"] = "";
			}
		}


		// ----- Begin Professor Verification ----- //
		$profCount = 0;
		if($data["prof_1_id"] != 0) {
			 if(mysqlib_get("SELECT COUNT(*) FROM `user` WHERE `id` = '".mysqlib_secure($data["prof_1_id"])."'", 0) != 1)
				$properness["prof_1_id"] = "invalid";
			$profCount++;
		}

		if($data["prof_2_id"] != 0) {
			 if(mysqlib_get("SELECT COUNT(*) FROM `user` WHERE `id` = '".mysqlib_secure($data["prof_2_id"])."'", 0) != 1)
				$properness["prof_2_id"] = "invalid";
			else if($data["prof_1_id"] == $data["prof_2_id"])
				$properness["prof_2_id"] = "double";
			$profCount++;
		}

		if($data["prof_3_id"] != 0) {
			 if(mysqlib_get("SELECT COUNT(*) FROM `user` WHERE `id` = '".mysqlib_secure($data["prof_3_id"])."'", 0) != 1)
				$properness["prof_3_id"] = "invalid";
			else if($data["prof_1_id"] == $data["prof_3_id"] || $data["prof_2_id"] == $data["prof_3_id"])
				$properness["prof_3_id"] = "double";
			$profCount++;
		}

		if($profCount == 0)
			$properness["prof_1_id"] = "empty";
		// ----- End Advisor Verification ----- //


		// ----- File ID Verifivation ----- //
		if(!isset($properness["file_id"]))
			if(mysqlib_get("SELECT COUNT(*) FROM `file_index` WHERE `id` = '".mysqlib_secure($data["file_id"])."' AND `temporary` = '1'", 0) == 1) {
				$temp = mysqlib_get("SELECT `real_name`, `system_name` FROM `file_index` WHERE `id` = '".mysqlib_secure($data["file_id"])."'", 1);
				$data["file_id"] = array("id" => $data["file_id"]);
				$data["file_id"]["name"] = $temp["real_name"];
				$data["file_id"]["size_b"] = filesize($_settings[upload][path].$temp["system_name"]);
				$data["file_id"]["size_kb"] = round($data["file_id"]["size_b"]/1024, 2);
				$data["file_id"]["size_mb"] = round($data["file_id"]["size_b"]/(1024*1024), 2);
			} else {
				$properness["file_id"] = "empty";
				unset($data["file_id"]);
			}
		break;
*/
	default:
		echo "something wrong in 'inc.entry_check.php'";
}

?>