<?php

/**
	AppSys - An application management system for PhD programs funded by the DFG.
	Copyright (C) 2010 Florian Junghanns

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
**/


function dal_getApplicationById ($application_id) {
	return dal_getApplication($application_id);
}

function dal_getApplicationByType ($type) {
	return dal_getApplication(NULL, $type);
}

function dal_getApplicationByStatus ($status) {
	return dal_getApplication(NULL, NULL, $status);
}

function dal_getApplication ($application_id = NULL, $type = NULL, $status = NULL) {

// ----- If the type is clear ----- //
	if($application_id != NULL || $type != NULL) {
		$typeAddition["field"] = "";
		$typeAddition["join"] = "";

		// ----- If type isn't set yet, get it. ----- //
		if(empty($type))
			$type = mysqlib_get("SELECT b.`name` FROM `application_detail` AS a JOIN `application_type` AS b ON (a.`id` = '".$application_id."' AND a.`type_id` = b.`id`)", 0);

		// ----- Begin: Specification of Result Array, specified by Type ----- //
		switch($type) {
		case "phd":
			$typeAddition["field"] .= ",
				k.`grad_degree` AS `degree`,
				k.`grad_gpa` AS `gpa`,
				k.`grad_year` AS `grad_year`,
				k.`grad_title` AS `grad_title`,
				k.`topic_1` AS `topic_1`,
				k.`topic_2` AS `topic_2`,
				k.`topic_3` AS `topic_3`,
				g_user.`id` AS `advisor_1_id`,
				CONCAT(g_user.`firstname`, ' ', g_user.`lastname`) AS `advisor_1_real_name`,
				g_user.`shortname` AS `advisor_1_short_name`,
				h_user.`id` AS `advisor_2_id`,
				CONCAT(h_user.`firstname`, ' ', h_user.`lastname`) AS `advisor_2_real_name`,
				h_user.`shortname` AS `advisor_2_short_name`,
				i_user.`id` AS `advisor_3_id`,
				CONCAT(i_user.`firstname`, ' ', i_user.`lastname`) AS `advisor_3_real_name`,
				i_user.`shortname` AS `advisor_3_short_name`";
			$typeAddition["join"] .= "
				LEFT JOIN `application_to_prof` AS g
					ON ( g.`application_id` = a.`id`
						AND g.`rank` = '1' )
				LEFT JOIN `user` AS g_user
					ON ( g.`user_id` = g_user.`id` )
				LEFT JOIN `application_to_prof` AS h
					ON ( h.`application_id` = a.`id`
						AND h.`rank` = '2' )
				LEFT JOIN `user` AS h_user
					ON ( h.`user_id` = h_user.`id` )
				LEFT JOIN `application_to_prof` AS i
					ON ( i.`application_id` = a.`id`
						AND i.`rank` = '3' )
				LEFT JOIN `user` AS i_user
					ON ( i.`user_id` = i_user.`id`)
				JOIN `application_phd_detail` AS k
					ON ( a.`id` = k.`id` )";
			break;

		case "pd":
			$typeAddition["field"] .= ",
				k.`inst_department` AS `inst_department`,
				k.`phd_advisor` AS `phd_advisor`,
				k.`phd_title` AS `phd_title`,
				k.`phd_degree` AS `phd_degree`,
				k.`phd_grade` AS `phd_grade`,
				k.`phd_time` AS `phd_time`,
				k.`topic` AS `topic`,
				g_user.`id` AS `prof_1_id`,
				CONCAT(g_user.`firstname`, ' ', g_user.`lastname`) AS `prof_1_real_name`,
				g_user.`shortname` AS `prof_1_short_name`,
				g_area.`name` AS `prof_1_area`,
				h_user.`id` AS `prof_2_id`,
				CONCAT(h_user.`firstname`, ' ', h_user.`lastname`) AS `prof_2_real_name`,
				h_user.`shortname` AS `prof_2_short_name`,
				h_area.`name` AS `prof_2_area`,
				i_user.`id` AS `prof_3_id`,
				CONCAT(i_user.`firstname`, ' ', i_user.`lastname`) AS `prof_3_real_name`,
				i_user.`shortname` AS `prof_3_short_name`,
				i_area.`name` AS `prof_3_area`";
			$typeAddition["join"] .= "
				LEFT JOIN `application_to_prof` AS g
					ON ( g.`application_id` = a.`id`
						AND g.`rank` = '1' )
				LEFT JOIN `user` AS g_user
					ON ( g.`user_id` = g_user.`id` )
				LEFT JOIN `user_to_area` AS g_u2a
					ON ( g.`user_id` = g_u2a.`user_id` )
				LEFT JOIN `area` AS g_area
					ON ( g_u2a.`area_id` = g_area.`id` )

				LEFT JOIN `application_to_prof` AS h
					ON ( h.`application_id` = a.`id`
						AND h.`rank` = '2' )
				LEFT JOIN `user` AS h_user
					ON ( h.`user_id` = h_user.`id` )
				LEFT JOIN `user_to_area` AS h_u2a
					ON ( h.`user_id` = h_u2a.`user_id` )
				LEFT JOIN `area` AS h_area
					ON ( h_u2a.`area_id` = h_area.`id` )

				LEFT JOIN `application_to_prof` AS i
					ON ( i.`application_id` = a.`id`
						AND i.`rank` = '3' )
				LEFT JOIN `user` AS i_user
					ON ( i.`user_id` = i_user.`id`)
				LEFT JOIN `user_to_area` AS i_u2a
					ON ( i.`user_id` = i_u2a.`user_id` )
				LEFT JOIN `area` AS i_area
					ON ( i_u2a.`area_id` = i_area.`id` )

				JOIN `application_pd_detail` AS k
					ON ( a.`id` = k.`id` )";
			break;

		default:
			break;
		}
		// ----- End: Specification of Result Array, specified by Type ----- //


		// ----- Begin: Assemble SQL query ----- //
		$strSQL = 
"			SELECT
				a.*,
				d.`name` AS `country`,
				e.`name` AS `nationality`,
				f.`name` AS `inst_country`,
				j.`real_name` AS `file_real_name`,
				j.`system_name` AS `file_system_name`,
				b.`name` AS `type`,
				c.`name` AS `status`"
				.$typeAddition["field"]."
			FROM `application_detail` AS a
				JOIN `application_type` AS b
					ON ( ";

		// ----- Begin: Insertion of (optional) ID condition ----- //
		if(!is_null($application_id))
			$strSQL .= "a.`id` = '".$application_id."'
						AND ";
		// ----- End: Insertion of (optional) ID condition ----- //

		// ----- Begin: Insertion of (optional) TYPE condition ----- //
		if(ctype_digit($type))
			$strSQL .= "b.`id` = '".$type."'
						AND ";
		else if(!empty($type))
			$strSQL .= "b.`name` = '".$type."'
						AND ";
		// ----- End: Insertion of (optional) TYPE condition ----- //

		$strSQL .= "a.`type_id` = b.`id`)
				JOIN `application_status` AS c
					ON ( ";

		// ----- Begin: Insertion of (optional) STATUS condition ----- //
		if(ctype_digit($status))
			$strSQL .= "c.`id` = '".$status."'
						AND ";
		else if(!empty($status))
			$strSQL .= "c.`name` = '".$status."'
						AND ";
		// ----- End: Insertion of (optional) STATUS condition ----- //

		$strSQL .= "a.`status_id` = c.`id` )
				LEFT JOIN `country` AS d
					ON ( a.`country_id` = d.`id` )
				LEFT JOIN `nationality` AS e
					ON ( a.`nationality_id` = e.`id` )
				LEFT JOIN `country` AS f
					ON ( a.`inst_country_id` = f.`id` )
				JOIN `file_index` AS j
					ON ( a.`file_id` = j.`id` )"
						.$typeAddition["join"];
		// ----- End: Assemble SQL query ----- //

		if(!empty($application_id))
			return mysqlib_get($strSQL, 1);
		else
			return mysqlib_get($strSQL);
	} else
// ----- End: If the type is clear ----- //


// ----- If the type is NOT clear ----- //
	if(empty($application_id) && empty($type)) {
		$strSQL = "
			SELECT
				a.*,
				d.`name` AS `country`,
				e.`name` AS `nationality`,
				f.`name` AS `inst_country`,
				CONCAT(g_user.`firstname`, ' ', g_user.`lastname`) AS `advisor_1_real_name`,
				g_user.`shortname` AS `advisor_1_short_name`,
				CONCAT(h_user.`firstname`, ' ', h_user.`lastname`) AS `advisor_2_real_name`,
				h_user.`shortname` AS `advisor_2_short_name`,
				CONCAT(i_user.`firstname`, ' ', i_user.`lastname`) AS `advisor_3_real_name`,
				i_user.`shortname` AS `advisor_3_short_name`,
				j.`real_name` AS `file_real_name`,
				j.`system_name` AS `file_system_name`,
				b.`name` AS `type`,
				c.`name` AS `status`
			FROM `application_detail` AS a
				JOIN `application_type` AS b
					ON ( a.`type_id` = b.`id`)
				JOIN `application_status` AS c
					ON ( ";

		// ----- Begin: Insertion of (optional) STATUS condition ----- //
		if(ctype_digit($status))
			$strSQL .= "c.`id` = '".$status."'
								AND ";
		else if(!empty($status))
			$strSQL .= "c.`name` = '".$status."'
								AND ";
		// ----- End: Insertion of (optional) STATUS condition ----- //

		$strSQL .= "a.`status_id` = c.`id` )
						JOIN `country` AS d
							ON ( a.`country_id` = d.`id` )
						JOIN `nationality` AS e
							ON ( a.`nationality_id` = e.`id` )
						JOIN `country` AS f
							ON ( a.`inst_country_id` = f.`id` )
						LEFT JOIN `application_to_prof` AS g
							ON ( g.`application_id` = a.`id`
								AND g.`rank` = '1' )
						LEFT JOIN `user` AS g_user
							ON ( g.`user_id` = g_user.`id` )
						LEFT JOIN `application_to_prof` AS h
							ON ( h.`application_id` = a.`id`
								AND h.`rank` = '2' )
						LEFT JOIN `user` AS h_user
							ON ( h.`user_id` = h_user.`id` )
						LEFT JOIN `application_to_prof` AS i
							ON ( i.`application_id` = a.`id`
								AND i.`rank` = '3' )
						LEFT JOIN `user` AS i_user
							ON ( i.`user_id` = i_user.`id`)
						JOIN `file_index` AS j
							ON ( a.`file_id` = j.`id` )";
		return mysqlib_get($strSQL);
	}
// ----- End: If the type is NOT clear ----- //
}


function dal_insertNewApplication ($data) {
	$data = mysqlib_secure($data);

	$strSQL = "
	INSERT INTO
		`application_detail`
		(
			`title`,
			`firstname`,
			`lastname`,
			`gender`,
			`birthday`,
			`place`,
			`country_id`,
			`nationality_id`,
			`email`,
			`inst_name`,
			`inst_place`,
			`inst_country_id`,
			`file_id`,
			`type_id`,
			`date`
		)
	VALUES (
		'".$data["title"]."',
		'".$data["firstname"]."',
		'".$data["lastname"]."',
		'".$data["gender"]."',
		'".$data["birthday"]."',
		'".$data["place"]."',
		'".$data["country_id"]."',
		'".$data["nationality_id"]."',
		'".$data["email"]."',
		'".$data["inst_name"]."',
		'".$data["inst_place"]."',
		'".$data["inst_country_id"]."',
		'".$data["file_id"]."',
		'".mysqlib_get("SELECT `id` FROM `application_type` WHERE `name` = '".$data["type"]."'", 0)."',
		'".time()."'
	)";
	mysql_query($strSQL);

	$application_id = mysql_insert_id();

	switch($data["type"]) {
	case "phd":
		$strSQL = "
			INSERT INTO
				`application_phd_detail`
				(
					`id`,
					`grad_degree`,
					`grad_gpa`,
					`grad_year`,
					`grad_title`,
					`topic_1`,
					`topic_2`,
					`topic_3`
				)
			VALUES (
				'".$application_id."',
				'".$data["grad_degree"]."',
				'".$data["grad_gpa"]."',
				'".$data["grad_year"]."',
				'".$data["grad_title"]."',
				'".$data["topic_1"]."',
				'".$data["topic_2"]."',
				'".$data["topic_3"]."'
			)";
		mysql_query($strSQL);
		$strSQL = "
			INSERT INTO
				`application_to_prof`
				(
					`application_id`,
					`user_id`,
					`rank`
				)
			VALUES (
				'".$application_id."',
				";
		for($i = 1; $i <= 3; $i++)
			if(isset($data["advisor_".$i."_id"]))
				mysql_query($strSQL."'".$data["advisor_".$i."_id"]."', '".$i."')");
			else
				break;
		return $application_id;

	case "pd":
		$strSQL = "
			INSERT INTO
				`application_pd_detail`
				(
					`id`,
					`inst_department`,
					`phd_advisor`,
					`phd_title`,
					`phd_degree`,
					`phd_grade`,
					`phd_time`,
					`topic`
				)
			VALUES (
				'".$application_id."',
				'".$data["inst_department"]."',
				'".$data["phd_advisor"]."',
				'".$data["phd_title"]."',
				'".$data["phd_degree"]."',
				'".$data["phd_grade"]."',
				'".$data["phd_time"]."',
				'".$data["topic"]."'
			)";
		mysql_query($strSQL);
		$strSQL = "
			INSERT INTO
				`application_to_prof`
				(
					`application_id`,
					`user_id`,
					`rank`
				)
			VALUES (
				'".$application_id."',
				";
		for($i = 1; $i <= 3; $i++)
			if(isset($data["prof_".$i."_id"]))
				mysql_query($strSQL."'".$data["prof_".$i."_id"]."', '".$i."')");
			else
				break;
		return $application_id;
	}
}


function dal_updateApplication ($data) {
	$data = mysqlib_secure($data);

	$strSQL = 
"	UPDATE
		`application_detail`
	SET
		`title` = '".			$data["title"]."',
		`firstname` = '".		$data["firstname"]."',
		`lastname` = '".		$data["lastname"]."',
		`gender` = '".			$data["gender"]."',
		`birthday` = '".		$data["birthday"]."',
		`place` = '".			$data["place"]."',
		`country_id` = '".		$data["country_id"]."',
		`nationality_id` = '".	$data["nationality_id"]."',
		`email` = '".			$data["email"]."',
		`inst_name` = '".		$data["inst_name"]."',
		`inst_place` = '".		$data["inst_place"]."',
		`inst_country_id` = '".	$data["inst_country_id"]."',
		`file_id` = '".			$data["file_id"]."',
		`notice` = '".			$data["notice"]."',
		`status_id` = '".		$data["status_id"]."',
		`validation` = '".		$data["validation"]."'
	WHERE
		`id` = '".$data["id"]."'";
	mysql_query($strSQL);


	switch($data["type"]) {

	case "phd":
		$strSQL =
	"	UPDATE
			`application_phd_detail`
		SET
			`grad_degree` = '".		$data["grad_degree"]."',
			`grad_gpa` = '".		$data["grad_gpa"]."',
			`grad_year` = '".		$data["grad_year"]."',
			`grad_title` = '".		$data["grad_title"]."',
			`topic_1` = '".			$data["topic_1"]."',
			`topic_2` = '".			$data["topic_2"]."',
			`topic_3` = '".			$data["topic_3"]."'
		WHERE
			`id` = '".$data["id"]."'";
		mysql_query($strSQL);

		$advisorCount = mysqlib_get("SELECT COUNT(*) FROM `application_to_prof` WHERE `application_id` = '".$data["id"]."'", 0);
		$advisorCounter;
		for($advisorCounter = 1; $advisorCounter <= $advisorCount; $advisorCounter++) {
			$strSQL =
	"		UPDATE
				`application_to_prof`
			SET
				`user_id` = '".$data["advisor_".$advisorCounter]."'
			WHERE
				`application_id` = '".$data["id"]."'
				AND `rank` = '".$advisorCounter."'";
			mysql_query($strSQL);
		}
		for(; $advisorCounter <= 3 && $data["advisor_".$advisorCounter] != 0; $advisorCounter++) {
			$strSQL =
	"		INSERT INTO
				`application_to_prof`
					(`application_id`, `user_id`, `rank`)
			VALUES (
				'".$data["id"]."',
				'".$data["advisor_".$advisorCounter]."',
				'".$advisorCounter."'
			)";
			mysql_query($strSQL);
		}
		break;

	case "pd":
		$strSQL =
	"	UPDATE
			`application_pd_detail`
		SET
			`inst_department` = '".	$data["inst_department"]."',
			`phd_advisor` = '".		$data["phd_advisor"]."',
			`phd_title` = '".		$data["phd_title"]."',
			`phd_degree` = '".		$data["phd_degree"]."',
			`phd_grade` = '".		$data["phd_grade"]."',
			`phd_time` = '".		$data["phd_time"]."',
			`topic` = '".			$data["topic"]."'
		WHERE
			`id` = '".$data["id"]."'";
		mysql_query($strSQL);

		$profCount = mysqlib_get("SELECT COUNT(*) FROM `application_to_prof` WHERE `application_id` = '".$data["id"]."'", 0);
		$profCounter;
		for($profCounter = 1; $profCounter <= $profCount; $profCounter++) {
			$strSQL =
	"		UPDATE
				`application_to_prof`
			SET
				`user_id` = '".$data["prof_".$profCounter]."'
			WHERE
				`application_id` = '".$data["id"]."'
				AND `rank` = '".$profCounter."'";
			mysql_query($strSQL);
		}
		for(; $profCounter <= 3 && $data["prof_".$profCounter] != 0; $profCounter++) {
			$strSQL =
	"		INSERT INTO
				`application_to_prof`
					(`application_id`, `user_id`, `rank`)
			VALUES (
				'".$data["id"]."',
				'".$data["prof_".$profCounter]."',
				'".$profCounter."'
			)";
			mysql_query($strSQL);
		}
		break;

	default:
		echo "error in dal.php, update_application";
		break;
	}
}


function dal_getTypeOfApplicationById ($application_id) {
	return mysqlib_get("SELECT b.`id` AS `id`, b.`name` AS `name` FROM `application_detail` AS a JOIN `application_type` AS b ON (a.`id` = '".$application_id."' AND a.`type_id` = b.`id`)", 1);
}

function dal_getStatusOfApplicationById ($application_id) {
	return mysqlib_get("SELECT b.`id` AS `id`, b.`name` AS `name` FROM `application_detail` AS a JOIN `application_status` AS b ON (a.`id` = '".$application_id."' AND a.`status_id` = b.`id`)", 1);
}

?>