<?php

/**
	AppSys - An application management system for PhD programs funded by the DFG.
	Copyright (C) 2010 Florian Junghanns

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
**/


/* ----- Contents ----- //

	- getData ( $filename )
			Gets data from a file in "data/".$filename; returns an array over all lines.

	- getUniqueMD5 ( $exArr = NULL )
			Returns a random MD5-Hash which is not in $exArr. If $exArr is no array, it equals "getRandomMD5()".

	- getRandomMD5 ( )
			Returns a random MD5-Hash.

	- postfieldhelper ( $fieldname, $conditiontype, $value, $optional )
			Returns an array which contains the given arguments in a specific structure. Needed for "inc.application_fields.php" and including/included files.

	- pfh ( $fieldname, $conditiontype, $value, $optional = false )
			Returns the same as function "postfieldhelper", but you can drop the last parameter if the field is mandatory.

	- isLeapYear ( $year )
			Returns wether the given year is a leapyear or not.

	- validateDate ( $day, $month, $year )
			Returns if the given date assembled by the three given parameters is a valid date. In the end it does the same as "checkdate()" (provided by PHP).

	- misc_
		- getTemplateForFileError ( $myError, $myDetail )
				Returns the error message that belongs to the error. Only for file errors, pre-processed.

		- apptable_create_rows ( $applications, $backlink )
				Returns the complete application overview table for the applications provided by $applications.

		- apptable_create_overview ( $type, $status, $mark_for )
				Creates the overview table for one specific advisor.

		- convertToUTF8 ( $text )
				Converts the given $text to UTF 8.

----- End of contents list ----- */


// Initialize randomizer (for function(s) 'getUniqueMD5(exArr)')
srand(microtime()*1000000);


function misc_sendMailToApplicant ($application_id) {
	return mailib_sendCheckedMailToApplicant($application_id);
}
function misc_sendAppliedMailToApplicant ($application_id) {
	return mailib_sendAppliedMailToApplicant($application_id);
}


/* Documentation of function getData (filename)
	Var:	filename		the name of the file in folder "data" which's lines are to read in an array given back.
	Returns:				The lines of the file $filename in an array.
*/
function getData ($filename) {
	$file = fopen("data/".$filename, "r");
	$content = fread($file, filesize("data/".$filename));
	fclose($file);
	$result = array();
	while($actPos = strpos("\n", $content)) {
		$result[sizeof($result)] = substr($content, 0, $actPos);
		$content = substr($content, $actPos+1);
	}
	$result[sizeof($result)] = $content;
	return $result;
}


/* Documentation of function getUniqueMD5 (exArr)
	Var:	exArr			An array which contains used md5 hashes.
	Returns:				An uniqe md5 hash which is not in exArr.
*/
function misc_getUniqueMD5 ($exArr = NULL) {
	if(!is_array($exArr))
		return getRandomMD5();
	else {
		$md5hash;
		while(in_array($md5hash = getRandomMD5(), $exArr))
			continue;
		return $md5hash;
	}
}

function getRandomMD5 () {
	return md5(microtime()*rand(1,100));
}

function getUniqueMD5 ($exArr) {
	return misc_getUniqueMD5($exArr);
}


function postfieldhelper ($fieldname, $conditiontype, $value, $optional) {
	return array("name" => $fieldname, "conditiontype" => $conditiontype, "value" => $value, "optional" => $optional);
}
function pfh ($fieldname, $conditiontype, $value, $optional = false) {
	return postfieldhelper($fieldname, $conditiontype, $value, $optional);
}


function isLeapYear ($year) {
	return ($year % 4 == 0 && ($year % 100 != 0 || $year % 400 == 0));
}
function validateDate ($day, $month, $year) {
	if($day < 1)
		return false;
	switch($month) {
		case 1:
		case 3:
		case 5:
		case 7:
		case 8:
		case 10:
		case 12:
			if($day > 31)
				return false;
			break;
		case 4:
		case 6:
		case 9:
		case 11:
			if($day > 30)
				return false;
			break;
		case 2:
			if(isLeapYear($year)) {
				if($day > 29)
					return false;
			} else
				if($day > 28)
					return false;
			break;
		default:
			return false;
	}
	return true;
}


function misc_getTemplateForFileError ($myError, $myDetail) {
	switch($myDetail) {
		case "move_uploaded_file":
			return str_replace("{>error-message<}", template_basic("application_field_error__move_uploaded"), template_basic("application_field_error_file_system"));
		case "undefined":
			return str_replace("{>error-message<}", template_basic("application_field_error__undefined"), template_basic("application_field_error_file_system"));
		case "size":
			return str_replace("{>max_size<}", $_settings[upload][max_size], template_basic("application_field_error_file_size"));
		case "file not complete":
			return template_basic("application_field_error_file_not_complete");
		case "type":
			return template_basic("application_field_error_file_type");
		default:
			return str_replace("{>error-code<}", $myDetail, str_replace("{>error-message<}", template_basic("application_field_error__code"), template_basic("application_field_error_file_system")));
	}
}


function misc_apptable_create_rows ($type, $applications, $mark_for = NULL) {
	global $user;

	$toMarkUnread;
	if(!empty($mark_for))
		$toMarkUnread = array_values(mysqlib_get("SELECT `application_id` FROM `unread` WHERE `user_id` = '".$mark_for."'", 1));

	switch($type) {

	case "phd":
		if(!empty($applications)) {
			$lines = "";
			foreach($applications AS $record) {
				$temp = template_basic("overview_table_row");
				$temp = str_replace("{>date<}", date("d.m.Y", $record["date"]), $temp);
				$temp = str_replace("{>name<}", $record[lastname].", ".$record[firstname], $temp);
				$temp = str_replace("{>nationality<}", $record[nationality], $temp);
				$temp = str_replace("{>profs<}", $record[advisor_1_short_name]
					. (!empty($record[advisor_2_short_name]) ? ", ".$record[advisor_2_short_name] : "")
					. (!empty($record[advisor_3_short_name]) ? ", ".$record[advisor_3_short_name] : ""), $temp);
				$temp = str_replace("{>id<}", $record[id], $temp);
				$temp = str_replace("{>file_id<}", $record[file_id], $temp);

				if($user["shortname"] == "DS") {
					$special = template_basic("shortnotice_input_field");
					$special = str_replace("{>shortnotice<}", $record["shortnotice"], $special);
					$special = str_replace("{>type<}", $type, $special);
					$special = str_replace("{>app_id<}", $record["id"], $special);
					$temp = str_replace("{>special<}", $special, $temp);
				} else
					if(empty($record["shortnotice"]))
						$temp = str_replace("{>special<}", "", $temp);
					else {
						$special = template_basic("shortnotice_display");
						$special = str_replace("{>shortnotice<}", $record["shortnotice"], $special);
						$special = str_replace("{>app_id<}", $record["id"], $special);
						$temp = str_replace("{>special<}", $special, $temp);
					}

				// Setting CSS-classes for line
				if(!empty($mark_for)) {
					if($mark_for == $record["advisor_1_id"] || $mark_for == $record["advisor_2_id"] || $mark_for == $record["advisor_3_id"])
						$temp = str_replace("{>css_class<}", "relevant {>css_class<}", $temp);
					$id_in_array = array_search($record["id"], $toMarkUnread);
					if($id_in_array != FALSE) {
						unset($toMarkUnread[$id_in_array]);
						$temp = str_replace("{>css_class<}", "unread {>css_class<}", $temp);
					}
				}
				$temp = str_replace("{>css_class<}", "", $temp);

				$lines .= $temp;
			}
			return $lines;
		}

		else {
			$temp = template_basic("overview_table_row_inactive");
			$temp = str_replace("{>date<}", "no entries", $temp);
			$temp = str_replace("{>name<}", "", $temp);
			$temp = str_replace("{>nationality<}", "", $temp);
			$temp = str_replace("{>advisors<}", "", $temp);
			return $temp;
		}

	case "pd":
		if(!empty($applications)) {
			$lines = "";
			foreach($applications AS $record) {
				// Inserting text into line
				$temp = template_basic("overview_table_row");
				$temp = str_replace("{>date<}", date("d.m.Y", $record['date']), $temp);
				$temp = str_replace("{>name<}", $record[lastname].", ".$record[firstname], $temp);
				$temp = str_replace("{>nationality<}", $record[nationality], $temp);
				$temp = str_replace("{>profs<}", $record[prof_1_short_name]
					. (!empty($record[prof_2_short_name]) ? ", ".$record[prof_2_short_name] : "")
					. (!empty($record[prof_3_short_name]) ? ", ".$record[prof_3_short_name] : ""), $temp);
				$temp = str_replace("{>id<}", $record[id], $temp);
				$temp = str_replace("{>file_id<}", $record[file_id], $temp);

				if($user["shortname"] == "DS") {
					$special = template_basic("shortnotice_input_field");
					$special = str_replace("{>shortnotice<}", $record["shortnotice"], $special);
					$special = str_replace("{>type<}", $type, $special);
					$special = str_replace("{>app_id<}", $record["id"], $special);
					$temp = str_replace("{>special<}", $special, $temp);
				} else
					if(empty($record["shortnotice"]))
						$temp = str_replace("{>special<}", "", $temp);
					else {
						$special = str_replace("{>shortnotice<}", $record["shortnotice"], template_basic("shortnotice_display"));
						$temp = str_replace("{>special<}", $special, $temp);
					}

				// Setting CSS-classes for line
				if(!empty($mark_for)) {
					if($mark_for == $record[prof_1_id] || $mark_for == $record[prof_2_id] || $mark_for == $record[prof_3_id])
						$temp = str_replace("{>css_class<}", "relevant {>css_class<}", $temp);
					$id_in_array = array_search($record[id], $toMarkUnread);
					if($id_in_array != FALSE) {
						unset($toMarkUnread[$id_in_array]);
						$temp = str_replace("{>css_class<}", "unread {>css_class<}", $temp);
					}
				}
				$temp = str_replace(" {>css_class<}", "", $temp);

				$lines .= $temp;
			}
			return $lines;
		}

		else {
			$temp = template_basic("overview_table_row_inactive");
			$temp = str_replace("{>date<}", "no entries", $temp);
			$temp = str_replace("{>name<}", "", $temp);
			$temp = str_replace("{>nationality<}", "", $temp);
			$temp = str_replace("{>advisors<}", "", $temp);
			return $temp;
		}

	}
}

function misc_apptable_create_overview ($type, $status, $mark_for) {
	$applications = dal_getApplication(NULL, $type, $status);
	$table = template_basic("overview_table_".$type);
	$rows = misc_apptable_create_rows($type, $applications, $mark_for);
	$table = str_replace("{>applications<}", $rows, $table);
	return $table;
}


function misc_convertToUTF8 ($text) {
	$det_encoding = mb_detect_encoding($text.'a');
	if ($det_encoding != false && $det_encoding != 'UTF-8') {
		$text = mb_convert_encoding($text, 'UTF-8', $det_encoding);
	}
	return $text;
}



?>